pspsps(1): call a catgirl from the Internyet to the Linux terminyal
===================================================================

> show processes: ps    
> show catgirls: pspsps    
    —@ln@chaos.social

pspsps(1) is a compyuter software to call an online catgirl nya.

![A screenshot of pspsps(1) invoking catgirls nya.](screenshot1.png)

pspsps(1) is nice and tries to guess the best options for you~ ฅ^•ﻌ•^ฅ    
for most ppl u can just call `pspsps` n it will work! probably (｡•̀ᴗ~)-✧

u can control colours, backnyends n stuff.    
call it with -h, the options should be self-explanyative.

if it looks wrong try with less colours!    
the more columns and lines in your terminyal, the better the drawings
will look.

catgirls are kindly provided by Safebooru.    
u can call other peoples too with `--tags`. like

![pspsps(1) now is calling catboys, nyaaan💕](screenshot2.png?v=2)

there are optinyons to make them smaller or bigger or save the images
or load from an image and meowre!    

![pspsps(1) is saving a drawing of catgirls in love](screenshot3.png)

u can also make drawings with nyascii characters nyanstead of colourful nyansi
art.  tho the mangas in nyascii dont look so good in most terminyal sizes, mew.

## the 'installation' how to

    pip3 install pspsps

## ✨🍭 search help 🍬💖

    pspsps -t femboy_hooters
show femboys from femboy hooters `(人*´∀｀)｡*ﾟ+`

    pspsps -t 'catgirl bunnygirl'
show catgirls together with bunnygirls

    pspsps -t catgirl,bunnygirl
show catgirls together with bunnygirls but easier to type

    pspsps -t 'catgirl kiss -hetero'
asks for catgirls kissing but no hetero >:(    
but sometimes hetero comes anyway (u.u )

## things a girl still wants to-do nya

 - add paginyation! so search can find catgirls further in the back
 - optinyon to show the URL of the nyoriginal post, nyot just the image URL!
 - and also support danbooru! it is a bit scary tho (^ ^);
 - tests, who is a girl kidding, nyobody does tests ever

## authoress

it’s me, mewlissa nya

minnabody let’s keep up the 'LINUX'! with spirit of gentleness and love no kokoro

*uw ûw úwu ŭ úwuwu*    
you all gay and cute.and.valid

*ũw ówüw ûvowo ũvòv òwo ùwu ùwu öv ŏvo ŏvo*    
thing difficult system that person few few own many many

*òwo-úwu õvò ówuv ûwuwu ù uw-üwu nyáa*    
ppl-cuties IMP do kind to your-selves please

*ŭ üv õvò üwo uvuwu ûvü!*    
and take IMP mass means labour!
